pub struct Json { /* private fields */ }Expand description
Json Response
Implementations
Sourceimpl Json
impl Json
Sourcepub fn select<T: DeserializeOwned>(&self, path: &str) -> Result<Vec<T>>
pub fn select<T: DeserializeOwned>(&self, path: &str) -> Result<Vec<T>>
Use jsonpath to select json fragments and convert them into structures
Sourcepub fn select_one<T: DeserializeOwned>(&self, path: &str) -> Result<T>
pub fn select_one<T: DeserializeOwned>(&self, path: &str) -> Result<T>
Use jsonpath to select json string fields
Sourcepub fn select_as_str(&self, path: &str) -> Result<String>
pub fn select_as_str(&self, path: &str) -> Result<String>
Use jsonpath to select json fields as string
Sourcepub fn select_one_as_str(&self, path: &str) -> Result<String>
pub fn select_one_as_str(&self, path: &str) -> Result<String>
Use jsonpath to select one json fields as string